Version - MediaWiki

Jump to content

# Version

## MediaWiki License

This wiki is powered by MediaWiki, copyright © 2001-2024 Magnus Manske, Brooke Vibber, Lee Daniel Crocker, Tim Starling, Erik Möller, Gabriel Wicke, Ævar Arnfjörð Bjarmason, Niklas Laxström, Domas Mituzas, Rob Church, Yuri Astrakhan, Aryeh Gregor, Aaron Schulz, Andrew Garrett, Raimond Spekking, Alexandre Emsenhuber, Siebrand Mazeland, Chad Horohoe, Roan Kattouw, Trevor Parscal, Bryan Tong Minh, Sam Reed, Victor Vasiliev, Rotem Liss, Platonides, Antoine Musso, Timo Tijhof, Daniel Kinzler, Jeroen De Dauw, Brad Jorsch, Bartosz Dziewoński, Ed Sanders, Moriel Schottlender, Kunal Mehta, James D. Forrester, Brian Wolff, Adam Shorland, DannyS712, Ori Livneh, Max Semenik, Amir Sarabadani, Derk-Jan Hartman, Petr Pchelko, others and translatewiki.net translators.

MediaWiki is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.

MediaWiki is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with this program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA or read it online.

## Installed software

Product | Version
--- | ---
MediaWiki | 1.43.0-wmf.13 (8eaf4e5) 22:54, 8 July 2024
PHP | 7.4.33 (fpm-fcgi)
ICU | 67.1
MariaDB | 10.6.17-MariaDB-log
wikidiff2 | 1.14.1
Pygments | 2.17.2
LilyPond | 2.22.0
Elasticsearch | 7.10.2
LuaSandbox | 4.1.2
Lua | 5.1.5

## Entry point URLs

Entry point | URL
--- | ---
Article path | `/wiki/$1`
Script path | `/w`
index.php | `/w/index.php`
api.php | `/w/api.php`
rest.php | `/w/rest.php`

## Installed skins

Skin | Version | License | Description | Authors
--- | --- | --- | --- | ---
Cologne Blue | – (82cf28c) 04:51, 22 June 2024 | GPL-2.0-or-later | A lightweight skin with minimal formatting | Lee Daniel Crocker and others
MinervaNeue | – (bbb3fc9) 07:36, 8 July 2024 | GPL-2.0-or-later | A responsive mobile first skin | Readers Web Team, Alex Hollender, Bahodir Mansurov, Florian Schmidt, Jan Drewniak, Joaquin Hernandez, Jon Robson, Juliusz Gonera, Piotr Miazga, Ryan Kaldari, Nick Ray, Sam Smith, Stephen Niedzielski and Volker E.
Modern | – (4fab17a) 05:08, 22 June 2024 | GPL-2.0-or-later | A blue/gray skin with sidebar and top bar. Derived from MonoBook | River Tarnell and others
MonoBook | – (2137759) 07:26, 4 July 2024 | GPL-2.0-or-later | The classic MediaWiki skin since 2004, named after the black-and-white photo of a book in the page background | Gabriel Wicke, Isarra Yos and others
Timeless | 0.9.1 (b4b1f77) 07:28, 1 July 2024 | GPL-2.0-or-later | A timeless skin designed after the Winter prototype by Brandon Harris, and various styles by the Wikimedia Foundation | Isarra Yos
Vector | 1.0.0 (dbc2b7d) 07:36, 8 July 2024 | GPL-2.0-or-later | Provides 2 Vector skins: 2011 - The Modern version of MonoBook with fresh look and many usability improvements. 2022 - The Vector built as part of the WMF Desktop Improvements project. | Readers Web Team, Trevor Parscal, Roan Kattouw, Alex Hollender, Bernard Wang, Clare Ming, Jan Drewniak, Jon Robson, Nick Ray, Sam Smith, Stephen Niedzielski and Volker E.

## Installed extensions

Special pages
Extension | Version | License | Description | Authors
--- | --- | --- | --- | ---
ApiFeatureUsage | 1.0 (55789a8) 01:33, 20 June 2024 | GPL-2.0-or-later | Get a summary of logged API feature usages for a user agent | Brad Jorsch
CentralAuth | – (65b1a2d) 21:11, 8 July 2024 | GPL-2.0-or-later | Merge account across wikis of the Wikimedia Foundation | Brion Vibber, Kunal Mehta, Sam Reed, Aaron Schulz, Brad Jorsch, Umherirrender, Marius Hoch, Andrew Garrett, Chris Steipp, Tim Starling, Gergő Tisza, Alexandre Emsenhuber, Victor Vasiliev, Glaisher, DannyS712, Peter Gehres, Bryan Davis, James D. Forrester, Taavi Väänänen and Alexander Vorwerk
CheckUser | 2.5 (0d327e5) 13:34, 8 July 2024 | GPL-2.0-or-later | Grants users with the appropriate permission the ability to check users' IP addresses and other information | Tim Starling, Aaron Schulz and Dreamy Jazz
CiteThisPage | – (43b88bf) 07:32, 8 July 2024 | GPL-2.0-or-later | Adds a citation special page and toolbox link | Ævar Arnfjörð Bjarmason and James D. Forrester
Collection | 1.8.0 (217febd) 07:32, 8 July 2024 | GPL-2.0-or-later | Create books | PediaPress GmbH, Siebrand Mazeland and Marcin Cieślak
Echo | – (bc08edb) 09:30, 8 July 2024 | MIT | System for notifying users about events and messages | Andrew Garrett, Ryan Kaldari, Benny Situ, Luke Welling, Kunal Mehta, Moriel Schottlender, Jon Robson and Roan Kattouw
ExtensionDistributor | – (a9718ab) 14:26, 20 June 2024 | GPL-2.0-or-later | Extension for distributing snapshot archives of extensions | Tim Starling, Sam Reed, Chad Horohoe and Kunal Mehta
Global Usage | 2.2.0 (b55ca2d) 07:33, 8 July 2024 | MIT | Special page to view global file usage | Bryan Tong Minh
GlobalPreferences | 0.1.2 (0b926f9) 22:07, 4 July 2024 | GPL-2.0-or-later | Allows users to set global preferences | Kunal Mehta, Sam Wilson and Max Semenik
Interwiki | 3.2 (83edeec) 07:33, 8 July 2024 | GPL-2.0-or-later | Adds a special page to view and edit the interwiki table | Stephanie Amanda Stevens, Alexandre Emsenhuber, Robin Pepermans, Siebrand Mazeland, Platonides, Raimond Spekking, Sam Reed, Jack Phoenix, Calimonius the Estrange and others
Linter | – (054abb7) 00:13, 3 July 2024 | GPL-2.0-or-later | Track lint errors from an external service and show them to users | Kunal Mehta, Arlo Breault and Subramanya Sastry
MassMessage | 0.5.0 (8e55a7a) 07:25, 1 July 2024 | GPL-2.0-or-later | Allows users to easily send a message to a list of users | Kunal Mehta and wctaiwan
NearbyPages | 1.0.0 (199900a) 07:25, 1 July 2024 | GPL-2.0-or-later | Adds Nearby special page |
Nuke | – (adad369) 07:33, 8 July 2024 | GPL-2.0-or-later | Gives administrators the ability to mass delete pages | Brion Vibber and Jeroen De Dauw
SiteMatrix | 1.6.0 (5bfdf9b) 07:26, 1 July 2024 | GPL-2.0-or-later | Displays a list of wikis | Tim Starling, Brion Vibber, Victor Vasiliev, Alexandre Emsenhuber and Sam Reed
TemplateSandbox | 1.1.0 (4285095) 07:42, 28 June 2024 | GPL-2.0-or-later | Renders a page transcluding templates from a sandbox | Brad Jorsch
Translate | 2024-07-16 (be3f85c) 17:25, 8 July 2024 | GPL-2.0-or-later | Special page for translating MediaWiki and beyond | Niklas Laxström, Siebrand Mazeland, Santhosh Thottingal, Amir E. Aharoni, Abijeet Patro and others
TranslationNotifications | 2018-08-05 (643fd15) 07:24, 4 July 2024 | GPL-2.0-or-later | Allows translators to sign up for translation notifications | Niklas Laxström, Amir E. Aharoni, Santhosh Thottingal, Siebrand Mazeland and Jon Harald Søby
UrlShortener | 1.2.0 (63161bb) 07:34, 8 July 2024 | Apache-2.0 | URL shortener for arbitrary URLs | Yuvi Panda, Prateek Saxena, Tim Starling, Kunal Mehta, MusikAnimal and Susana Molinar

Editors
Extension | Version | License | Description | Authors
--- | --- | --- | --- | ---
CodeEditor | – (faf23a2) 05:06, 20 June 2024 | GPL-2.0-or-later AND BSD-3-Clause | Syntax-highlighted editing for JavaScript and CSS pages using Ace editor | Brion Vibber and Derk-Jan Hartman
CodeMirror | 5.0.0 (a1770cb) 13:34, 8 July 2024 | GPL-2.0-or-later | Provides syntax highlighting in wikitext editor | Pavel Astakhov, Florian Schmidt, Marijn Haverbeke, MusikAnimal and CodeMirror contributors
VisualEditor | – (12ef5b7) 07:34, 8 July 2024 | MIT | Visual editor for MediaWiki | Alex Monk, Bartosz Dziewoński, C. Scott Ananian, Christian Williams, David Lynch, Ed Sanders, Inez Korczyński, James D. Forrester, Moriel Schottlender, Roan Kattouw, Rob Moen, Subramanya Sastry, Thalia Chan, Timo Tijhof, Trevor Parscal and others
WikiEditor | 0.5.4 (1554d73) 07:25, 4 July 2024 | GPL-2.0-or-later | Provides an advanced, extensible wikitext editing interface | Derk-Jan Hartman, Trevor Parscal, Roan Kattouw, Nimish Gautam and Adam Miller

Parser hooks
Extension | Version | License | Description | Authors
--- | --- | --- | --- | ---
Babel | – (62fe9a4) 06:40, 8 July 2024 | GPL-2.0-or-later | Adds the `#babel` parser function to allow automated generation of a babel userbox column with the ability to include custom templates | Robert Leverington, Thiemo Kreuz, Legoktm, Nikerabbit, Amir Aharoni and Ricordisamoa
CategoryTree | – (57e3556) 07:32, 8 July 2024 | GPL-2.0-or-later | Dynamically navigate the category structure | Daniel Kinzler
CharInsert | – (09eb770) 07:32, 8 July 2024 | GPL-2.0-or-later | Allows creation of JavaScript box for inserting non-standard characters | Brion Vibber
Cite | – (1b5c3f2) 23:57, 8 July 2024 | GPL-2.0-or-later | Adds `<ref>` and `<references>` tags for citations | Ævar Arnfjörð Bjarmason, Andrew Garrett, Brion Vibber, Ed Sanders, Marius Hoch, Steve Sanbeg, Trevor Parscal and others
DynamicPageList | 1.7.0 (e06f5dd) 07:50, 19 June 2024 | GPL-2.0-or-later | Outputs a bulleted list of the most recent items residing in a category, or an intersection of several categories | Amgine and IlyaHaykinson
EasyTimeline | – (e847fe3) 18:02, 5 July 2024 | GPL-2.0-only | Adds `<timeline>` tag to create timelines | Erik Zachte
ImageMap | – (ef30c83) 01:50, 21 June 2024 | GPL-2.0-or-later | Allows client-side clickable image maps using `<imagemap>` tag | Tim Starling and Arlo Breault
InputBox | 0.3.0 (5b948c7) 07:13, 26 June 2024 | MIT | Allow inclusion of predefined HTML forms | Erik Moeller, Leonardo Pimenta, Rob Church, Trevor Parscal and DaSch
Kartographer | – (6a0ed48) 07:33, 8 July 2024 | MIT | Allows maps to be added to the wiki pages | Yuri Astrakhan, Max Semenik, Ed Sanders, Julien Girault and others
LabeledSectionTransclusion | – (2f996da) 06:55, 22 June 2024 | GPL-2.0-or-later | Adds `#lst` and `#lstx` functions and `<section>` tag, enables marked sections of text to be transcluded | Steve Sanbeg
Math | – (7dcbd42) 07:33, 8 July 2024 | GPL-2.0-or-later | Render mathematical formulas between `<math>` ... `</math>` tags | Tomasz Wegrzanowski, Brion Vibber, Moritz Schubotz, Derk-Jan Hartman, André Greiner-Petter and Johannes Stegmüller
ParserFunctions | 1.6.1 (7544755) 07:33, 8 July 2024 | GPL-2.0-or-later | Enhance parser with logical functions | Tim Starling, Robert Rohde, Ross McClure and Juraj Simlovic
Phonos | 0.1.0 (b497e31) 07:33, 8 July 2024 | GPL-2.0-or-later | Provide text-to-speech functionality for a range of languages | Wikimedia Community Tech Team
Poem | – (cb94b96) 11:13, 21 June 2024 | CC0-1.0 | Adds `<poem>` tag for poem formatting | Nikola Smolenski, Brion Vibber and Steve Sanbeg
RSS feed | 2.25.1 (2cd2ccc) 16:49, 21 June 2024 | GPL-2.0-or-later | Displays RSS feeds on MediaWiki pages in a standard or in user-definable formats using template pages | Kellan Elliott-McCrea, mutante, Daniel Kinzler, Rdb, Mafs, Alxndr, Thomas Gries, Chris Reigrut, K001, Jack Phoenix, Jeroen De Dauw and Mark A. Hershberger
Score | 0.3.0 (4fb1c09) 07:26, 1 July 2024 | GPL-3.0-or-later | Adds a tag for rendering musical scores with LilyPond | Alexander Klauer and Étienne Beaulé
Scribunto | – (c684be1) 21:11, 8 July 2024 | GPL-2.0-or-later AND MIT | Framework for embedding scripting languages into MediaWiki pages | Victor Vasiliev, Tim Starling and Brad Jorsch
SyntaxHighlight | 2.0 (0249ef7) 16:30, 5 July 2024 | GPL-2.0-or-later | Provides syntax highlighting `<syntaxhighlight>` using Pygments - Python syntax highlighter | Brion Vibber, Tim Starling, Rob Church, Niklas Laxström, Ori Livneh and Ed Sanders
TemplateData | 0.1.2 (3bc25f0) 15:44, 5 July 2024 | GPL-2.0-or-later | Implements data storage for template parameters (using JSON) | Timo Tijhof, Moriel Schottlender, James D. Forrester, Trevor Parscal, Bartosz Dziewoński, Marielle Volz and others
TemplateStyles | 1.0 (02f0c3f) 07:34, 8 July 2024 | GPL-2.0-or-later | Implement per-template style sheets | Brad Jorsch and Marc A. Pelletier
WikiHiero | 1.1 (667d94c) 07:34, 8 July 2024 | GPL-2.0-or-later | Adds `<hiero>` tag to display hieroglyphs | Guillaume Blanchard and Max Semenik

Media handlers
Extension | Version | License | Description | Authors
--- | --- | --- | --- | ---
3D | 0.0.1 (3cc0fef) 00:45, 20 June 2024 | GPL-2.0-or-later | Provides support for 3D file formats | Gilles Dubuc
PagedTiffHandler | – (cdb5d22) 07:40, 22 June 2024 | GPL-2.0-or-later | Handler for viewing TIFF files in image mode | HalloWelt! Medienwerkstatt GmbH, Sebastian Ulbricht, Daniel Lynge, Marc Reymann and Markus Glaser for Wikimedia Deutschland
PDF Handler | – (6b8f8fd) 10:39, 21 June 2024 | GPL-2.0-or-later | Handler for viewing PDF files in image mode | Martin Seidel and Mike Połtyn
TimedMediaHandler | 0.6.0 (ffae44d) 13:49, 8 July 2024 | GPL-2.0-or-later | Handler for audio, video and timed text, with format support for WebM, Ogg Theora, Vorbis, srt | Michael Dale, Jan Gerber, Derk-Jan Hartman, Brooke Vibber, Tim Starling and others

Spam prevention
Extension | Version | License | Description | Authors
--- | --- | --- | --- | ---
Abuse Filter | – (98eab47) 12:42, 8 July 2024 | GPL-2.0-or-later | Applies automatic heuristics to edits | Andrew Garrett, Daimona Eaytoy, Marius Hoch, River Tarnell and Victor Vasiliev
AntiSpoof | – (aca03af) 07:46, 5 July 2024 | GPL-2.0-or-later | Blocks the creation of accounts with mixed-script, confusing and similar usernames | Brion Vibber
ConfirmEdit | 1.6.0 (73055f3) 07:32, 8 July 2024 | GPL-2.0-or-later | Provides CAPTCHA techniques to protect against spam and password-guessing | Brion Vibber, Florian Schmidt, Sam Reed and others
FancyCaptcha | – | GPL-2.0-or-later | Fancy CAPTCHA generator for Confirm Edit | Brion Vibber and others
SpamBlacklist | – (1912060) 02:07, 22 June 2024 | GPL-2.0-or-later | Regex-based anti-spam tool allowing to block list URLs in pages and email addresses for registered users | Tim Starling, John Du Hart and Daniel Kinzler
TitleBlacklist | 1.5.0 (3b51c90) 07:26, 24 June 2024 | GPL-2.0-or-later | Allows administrators to forbid creation of pages and user accounts according to a list of disallowed and allowed titles | Victor Vasiliev and Fran Rogers
TorBlock | 1.1.0 (fa7d322) 03:37, 22 June 2024 | GPL-2.0-or-later | Allows Tor exit nodes to be blocked from editing a wiki | Andrew Garrett

API
Extension | Version | License | Description | Authors
--- | --- | --- | --- | ---
PageImages | – (609bdad) 07:42, 21 June 2024 | WTFPL | Collects information about images used on page | Max Semenik

Wikibase
Extension | Version | License | Description | Authors
--- | --- | --- | --- | ---
EntitySchema | – (8176362) 08:21, 5 July 2024 | GPL-2.0-or-later | Store and discuss Schemas for Wikibase entities | The Wikidata team
WikibaseClient | – (5e834e4) 15:36, 8 July 2024 | GPL-2.0-or-later | Client for the Wikibase extension | The Wikidata team and others
WikibaseLexeme | – (730ebcd) 07:43, 28 June 2024 | GPL-2.0-or-later | Handle Lexeme entity type | The Wikidata team
WikimediaBadges | – (d56906b) 05:39, 19 June 2024 | GPL-2.0-or-later | Default themes to display badges on Wikimedia projects | Bene* and Marius Hoch

Other
Extension | Version | License | Description | Authors
--- | --- | --- | --- | ---
AdvancedSearch | – (890b66f) 07:31, 8 July 2024 | GPL-2.0-or-later | Easy access to advanced search capabilities on Special:Search | Wikimedia Deutschland Technical Wishes Team, Thiemo Kreuz, Gabriel Birke, Tonina Zhelyazkova, Christoph Jauera, Kai Nissen and Tim Eulitz
BetaFeatures | 0.1 (f49eb33) 07:46, 5 July 2024 | GPL-2.0-or-later | Lets user enable or disable features on the wiki that are still not ready for prime-time | MarkTraceur (Mark Holmquist) and others
BounceHandler | 1.0 (e3bfbd6) 03:33, 20 June 2024 | GPL-2.0-or-later | Helps in handling email bounces for MediaWiki | Tony Thomas, Kunal Mehta, Jeff Green and Sam Reed
Campaigns | 0.2.0 (fab5d02) 07:23, 4 July 2024 | GPL-2.0-or-later | Identifies the campaign leading to an account creation | S Page
CentralNotice | 2.6.1 (b6140a9) 13:26, 25 March 2024 | GPL-2.0-or-later | Adds a central sitenotice | Elliott Eggleston, Tomasz Finc, Andrew Russell Green, Ryan Kaldari, Trevor Parscal, Matthew Walker, Adam Roses Wight, Brion Vibber and others
CirrusSearch | – (b43b5d0) 17:39, 8 July 2024 | GPL-2.0-or-later | Elasticsearch-powered search for MediaWiki | Nik Everett, Chad Horohoe, Erik Bernhardson and others
Citoid | 0.3.0 (355b370) 07:32, 8 July 2024 | MIT | Provides access points between the citoid service and MediaWiki | Marielle Volz, Moriel Schottlender, Ed Sanders and others
CLDR | 4.14.0 (b3df807) 09:44, 8 July 2024 | GPL-2.0-or-later | Extension which provides localised language names based on CLDR data | Niklas Laxström, Siebrand Mazeland, Ryan Kaldari and Sam Reed
CommonsMetadata | – (bbf78f0) 05:27, 20 June 2024 | GPL-2.0-or-later | Extends the "extmetadata" property of the image information API module to include information stored in image description pages that use the templates commonly used on Wikimedia Commons | Brian Wolff
Disambiguator | 1.4 (893c7fe) 07:21, 26 June 2024 | MIT | Adds the tag `__DISAMBIG__` to mark disambiguation pages | Ryan Kaldari
Discussion tools | 0.0.0 (81871bc) 07:32, 8 July 2024 | MIT | Tools to enhance discussion pages. |
DismissableSiteNotice | 1.0.1 (f776efd) 06:53, 20 June 2024 | GPL-2.0-or-later | Allows users to close the sitenotice | Brion Vibber, Kevin Israel and Dror S.
Elastica | 6.2.0 (58005aa) 15:34, 1 July 2024 | GPL-2.0-or-later | Base Elasticsearch functionality for other extensions by providing Elastica library | Nik Everett and Chad Horohoe
ElectronPdfService | – (dafaf20) 07:47, 5 July 2024 | GPL-2.0-or-later | Adds browser based PDF rendering support through Electron PDF service | Wikimedia Deutschland Technical Wishes Team, Tobias Gritschacher, Addshore and Christoph Jauera
EventBus | 0.5.0 (61aadef) 15:04, 28 June 2024 | GPL-2.0-or-later | Propagates change information to a RESTful event service | Eric Evans, Petr Pchelko and Marko Obrovac
EventLogging | – (b545408) 08:58, 8 July 2024 | GPL-2.0-or-later | Framework for logging events from client-side code | Ori Livneh, Timo Tijhof, S Page, Matthew Flaschen and others
EventStreamConfig | – (5dfe2a7) 12:19, 20 June 2024 | GPL-2.0-or-later | Exposes event stream config in an API endpoint. Can also be used to expose configs via ResourceLoader | Andrew Otto
FeaturedFeeds | – (004eaac) 17:28, 20 June 2024 | WTFPL | Adds syndication feeds of wiki's featured content | Max Semenik
FileExporter | – (eda7147) 05:36, 22 June 2024 | GPL-2.0-or-later | Easy exporting of files to another wiki | Wikimedia Deutschland Technical Wishes Team, Addshore, Andrew Kostka, Christoph Jauera and Thiemo Kreuz
Flow | 1.2.0 (8fd5f3d) 07:32, 8 July 2024 | GPL-2.0-or-later | Discussion system | Erik Bernhardson, Stephane Bisson, Matthew Flaschen, Andrew Garrett, Shahyar Ghobadpour, Pau Giner, Roan Kattouw, Chris McMahon, Kunal Mehta, Matthias Mullie, S Page, Jon Robson, Moriel Schottlender, Benny Situ and Volker E.
Gadgets | – (163a891) 07:32, 8 July 2024 | GPL-2.0-or-later | Lets users select custom CSS and JavaScript gadgets in their preferences | Daniel Kinzler, Max Semenik, Timo Tijhof and Siddharth VP
GlobalBlocking | – (9b4c444) 07:32, 8 July 2024 | GPL-2.0-or-later | Allows accounts, IP addresses, and IP ranges to be blocked across multiple wikis | Andrew Garrett
Global CSS/JS | 3.4.0 (e9d4e77) 07:25, 1 July 2024 | GPL-2.0-or-later | Allows CSS and JavaScript on a central wiki to be loaded for all connected wikis | Ryan Schmidt, Szymon Świerkosz and Kunal Mehta
GlobalUserPage | 0.11.1 (536c3bc) 07:33, 8 July 2024 | GPL-3.0-or-later | Automatically fetches user pages from a central wiki | Kunal Mehta and Jack Phoenix
GuidedTour | 2.0 (857e41e) 07:23, 20 June 2024 | Apache-2.0 | Allows pages to provide a popup guided tour to assist new users | Munaf Assaf, Terry Chay, Matthew Flaschen, Pau Giner, Ori Livneh, Rob Moen, S Page, Sam Smith, Moiz Syed, Luke Welling and others
InterwikiSorting | – (b3c4cd5) 06:06, 22 June 2024 | GPL-2.0-or-later | Sort interwiki links | Addshore, Nikola Smolenski, Katie Filbert and Thiemo Kreuz
IP Info | 0.0.0 (91d375f) 07:25, 24 June 2024 | MIT | Provides information about an IP address. |
JsonConfig | 1.2.0 (7a0ed33) 07:49, 2 July 2024 | GPL-2.0-or-later | Allows JSON configuration to be stored in a wiki | Yuri Astrakhan and Eranroz
Liquid Threads | 2.3-alpha (27f80d2) 07:33, 8 July 2024 | GPL-2.0-or-later | Add threading discussions to talk pages | David McCabe and Andrew Garrett
LoginNotify | 0.1 (583a669) 07:33, 8 July 2024 | MIT | Notify users about suspicious logins from unfamiliar devices and/or IP addresses | Brian Wolff
MediaModeration | 2.0.0 (fbaad6a) 12:33, 26 June 2024 | GPL-2.0-or-later | Service for detecting matches against known child exploitation image hash datasets. | Core Platform & Trust and Safety Teams and Trust and Safety Product Team
MobileApp | – (a5fd770) 14:16, 8 July 2024 | GPL-2.0-or-later | Serves styles and scripts for use in the Wikimedia Mobile applications | Yuvi Panda
MobileFrontend | 2.4.1 (08be584) 08:09, 8 July 2024 | GPL-2.0-or-later | Helps improve the mobile presence of a MediaWiki instance | Patrick Reilly, Max Semenik, Jon Robson, Arthur Richards, Brion Vibber, Juliusz Gonera, Ryan Kaldari, Florian Schmidt, Rob Moen, Sam Smith and others
MultimediaViewer | – (3c1ece1) 16:36, 8 July 2024 | GPL-2.0-or-later | Expand thumbnails in a larger size in a fullscreen interface | Gergő Tisza, Gilles Dubuc, Mark Holmquist, Simon Legner, Ed Sanders, Pau Giner, James D. Forrester, Željko Filipin, fomafix, Volker E, Kunal Mehta, Umherirrender, Timo Tijhof, Aaron Arcos, Thiemo Kreuz, Matthias Mullie, Jon Robson, Derk-Jan Hartman, Chris McMahon, Bartosz Dziewoński and others
NavigationTiming | – (734e6c7) 16:51, 9 June 2024 | GPL-2.0-or-later | Adds client-side latency measurements logging | Patrick Reilly, Ori Livneh, Asher Feldman, Timo Tijhof, Ian Marlier, Gilles Dubuc, Peter Hedenskog, Larissa Gaulia and Barakat Ajadi
Newsletter | 1.2.1 (6aec8d8) 07:48, 5 July 2024 | GPL-2.0-or-later | Enables users to publish and subscribe to newsletters | Siebrand Mazeland, Tina Johnson and Tony Thomas
OATHAuth | 0.5.0 (47c6455) 07:33, 8 July 2024 | GPL-2.0-or-later AND GPL-3.0-or-later | Provides authentication support using HMAC based one-time passwords | Ryan Lane, Robert Vogel <vogel@hallowelt.com>, Dejan Savuljesku <savuljesku@hallowelt.com> and Taavi Väänänen
OAuth | 1.1.0 (a141760) 07:33, 8 July 2024 | GPL-2.0-or-later | Allows usage of OAuth 1.0a and OAuth 2.0 for API authorization | Aaron Schulz, Chris Steipp, Brad Jorsch, Robert Vogel and Dejan Savuljesku
PageViewInfo | – (fa1f889) 07:26, 1 July 2024 | GPL-3.0-or-later | Adds page view information to the info action | Kunal Mehta and Gergő Tisza
ParserMigration | 2.0.0 (a7afe40) 07:33, 8 July 2024 | CC0-1.0 | Parser migration tool | Tim Starling, C. Scott Ananian and others
ReadingLists | 0.1.0 (549adae) 22:09, 4 July 2024 | GPL-2.0-or-later | Allows users to manage private lists of articles, such as bookmarks or "Read Later" lists. | Gergő Tisza
RealMe | – (f3b9066) 07:26, 1 July 2024 | GPL-2.0-or-later | Allows verifying URLs used on user pages. | Taavi Väänänen
RevisionSlider | – (337ef44) 07:33, 8 July 2024 | GPL-2.0-or-later | Shows a slider allowing selecting and comparing of revisions on a diff page | Wikimedia Deutschland Technical Wishes Team, Addshore, Leszek Manicki, Jakob Warkotsch, Tobias Gritschacher and Christoph Jauera
SecureLinkFixer | – (813cea7) 07:33, 8 July 2024 | GPL-3.0-or-later | Rewrites URLs to HTTPS if domain always requires HTTPS | Kunal Mehta
SecurePoll | 3.0.0 (6ccecc1) 07:26, 1 July 2024 | GPL-2.0-or-later | Extension for elections and surveys | Tim Starling and others
TemplateWizard | 0.1.0 (770caaf) 07:21, 27 June 2024 | MIT | A WikiEditor add-on that provides a template-insertion wizard | Sam Wilson
TextExtracts | – (e623c55) 19:04, 5 July 2024 | GPL-2.0-or-later | Provides plain-text or limited HTML extracts of page content | Max Semenik
Thanks | 1.2.0 (94ec2c7) 07:34, 8 July 2024 | MIT | Adds links for thanking users for edits, comments, etc. | Ryan Kaldari, Benjamin Chen and Wctaiwan
TheWikipediaLibrary | 1.0.1 (31be232) 07:50, 2 July 2024 | MIT | Notify users of their eligibility for the Wikipedia Library when they cross the edit count and account age thresholds | Kavitha Muthu and Roan Kattouw
TrustedXFF | 2.0.0 (afce29a) 03:37, 22 June 2024 | GPL-2.0-or-later | Handling of a list of trusted proxy addresses (XFF project) | Tim Starling and Sam Reed
TwoColConflict | – (bc7d2fe) 07:24, 4 July 2024 | GPL-2.0-or-later | Showing a side-by-side edit merge screen for edit conflict resolution | Wikimedia Deutschland Technical Wishes Team, Christoph Jauera, Addshore, Andrew Kostka, Thiemo Kreuz and Adam Wight
UniversalLanguageSelector | 2024-07-16 (f8c60b3) 07:34, 8 July 2024 | GPL-2.0-or-later OR MIT | Gives the user several ways to select a language and to adjust language settings | Alolita Sharma, Amir Aharoni, Arun Ganesh, Brandon Harris, Kartik Mistry, Niharika Kohli, Niklas Laxström, Pau Giner, Santhosh Thottingal, Siebrand Mazeland and others
WebAuthn | 1.0.0 (e33016d) 07:34, 8 July 2024 | GPL-2.0-or-later AND GPL-3.0-or-later | Provides authentication support using WebAuthn protocol | Robert Vogel <vogel@hallowelt.com> and Dejan Savuljesku <savuljesku@hallowelt.com>
WikiLove | 1.3.1 (f0b2dda) 17:47, 2 July 2024 | MIT | Adds an interface for facilitating positive user feedback to user talk pages | Ryan Kaldari, Jan Paul Posma, Sam Reed and others
WikimediaEvents | 1.2.0 (d0e1415) 07:26, 1 July 2024 | GPL-2.0-or-later | Logs Wikimedia-specific events using EventLogging | Matthew Flaschen, Ori Livneh and Benny Situ
WikimediaMessages | – (6847a1b) 11:27, 8 July 2024 | GPL-2.0-or-later | Wikimedia specific messages | Tim Starling, Siebrand Mazeland, James D. Forrester and Multichill
XAnalytics | 0.3 (bf7e1bb) 07:15, 19 June 2024 | GPL-2.0-or-later | Emit analytics data via an X-Analytics header | Ori Livneh

## Installed libraries

### Installed server-side libraries

Library | Version | License | Description | Authors
--- | --- | --- | --- | ---
bacon/bacon-qr-code | 2.0.8 | BSD-2-Clause | BaconQrCode is a QR code generator for PHP. | Ben Scholzen 'DASPRiD'
beberlei/assert | 3.3.2 | BSD-2-Clause | Thin assertion library for input validation in business models. | Benjamin Eberlei and Richard Quadling
brick/math | 0.8.17 | MIT | Arbitrary-precision arithmetic library |
christian-riesen/base32 | 1.6.0 | MIT | Base32 encoder/decoder according to RFC 4648 | Christian Riesen
composer/ca-bundle | 1.5.0 | MIT | Lets you find a path to the system CA bundle, and includes a fallback to the Mozilla CA bundle. | Jordi Boggiano
composer/semver | 3.4.0 | MIT | Semver library that offers utilities, version constraint parsing and validation. | Nils Adermann, Jordi Boggiano and Rob Bast
cssjanus/cssjanus | 2.1.1 | Apache-2.0 | Convert CSS stylesheets between left-to-right and right-to-left. | Roan Kattouw, Trevor Parscal and Timo Tijhof
dasprid/enum | 1.0.5 | BSD-2-Clause | PHP 7.1 enum implementation | Ben Scholzen 'DASPRiD'
data-values/common | 1.1.0 | GPL-2.0-or-later | Contains common implementations of the interfaces defined by DataValuesInterfaces | Jeroen De Dauw
data-values/data-values | 3.1.0 | GPL-2.0-or-later | Defines the DataValue interface and some trivial implementations | Jeroen De Dauw
data-values/geo | 4.4.0 | GPL-2.0-or-later | Geographical value objects, parsers and formatters | Jeroen De Dauw and The Wikidata team
data-values/interfaces | 1.0.0 | GPL-2.0-or-later | Defines interfaces for ValueParsers, ValueFormatters and ValueValidators | Jeroen De Dauw
data-values/number | 0.12.3 | GPL-2.0-or-later | Numerical value objects, parsers and formatters | Daniel Kinzler and Thiemo Kreuz
data-values/serialization | 1.2.5 | GPL-2.0-or-later | Serializers and deserializers for DataValue implementations | Jeroen De Dauw
data-values/time | 1.1.2 | GPL-2.0-or-later | Time value objects, parsers and formatters | The Wikidata team
defuse/php-encryption | 2.4.0 | MIT | Secure PHP Encryption Library | Taylor Hornby and Scott Arciszewski
diff/diff | 3.3.1 | BSD-3-Clause | Small standalone library for representing differences between data structures, computing such differences, and applying them as patches | Jeroen De Dauw
elasticsearch/elasticsearch | 7.17.1 | Apache-2.0 and LGPL-2.1-only | PHP Client for Elasticsearch | Zachary Tong and Enrico Zimuel
endroid/qr-code | 4.6.1 | MIT | Endroid QR Code | Jeroen van den Enden
ezimuel/guzzlestreams | 3.1.0 | MIT | Fork of guzzle/streams (abandoned) to be used with elasticsearch-php | Michael Dowling
ezimuel/ringphp | 1.2.2 | MIT | Fork of guzzle/RingPHP (abandoned) to be used with elasticsearch-php | Michael Dowling
fgrosse/phpasn1 | 2.5.0 | MIT | A PHP Framework that allows you to encode and decode arbitrary ASN.1 structures using the ITU-T X.690 Encoding Rules. | Friedrich Große and All contributors
firebase/php-jwt | 6.10.0 | BSD-3-Clause | A simple library to encode and decode JSON Web Tokens (JWT) in PHP. Should conform to the current spec. | Neuman Vong and Anant Narayanan
geoip2/geoip2 | 2.13.0 | Apache-2.0 | MaxMind GeoIP2 PHP API | Gregory J. Oschwald
guzzlehttp/guzzle | 7.8.1 | MIT | Guzzle is a PHP HTTP client library | Graham Campbell, Michael Dowling, Jeremy Lindblom, George Mponos, Tobias Nyholm, Márk Sági-Kazár and Tobias Schultze
guzzlehttp/promises | 2.0.2 | MIT | Guzzle promises library | Graham Campbell, Michael Dowling, Tobias Nyholm and Tobias Schultze
guzzlehttp/psr7 | 2.6.2 | MIT | PSR-7 message implementation that also provides common utility methods | Graham Campbell, Michael Dowling, George Mponos, Tobias Nyholm, Márk Sági-Kazár, Tobias Schultze and Márk Sági-Kazár
jakobo/hotp-php | 2.0.0 | BSD-3-Clause | HOTP simplifies One Time Password systems for PHP Authentication | Jakob Heuser
james-heinrich/getid3 | 1.9.23 | GPL-1.0-or-later, LGPL-3.0-only and MPL-2.0 | PHP script that extracts useful information from popular multimedia file formats |
justinrainbow/json-schema | 5.2.13 | MIT | A library to validate a json schema. | Bruno Prieto Reis, Justin Rainbow, Igor Wiedler and Robert Schönthal
lcobucci/clock | 2.0.0 | MIT | Yet another clock abstraction | Luís Cobucci
lcobucci/jwt | 4.1.5 | BSD-3-Clause | A simple library to work with JSON Web Token and JSON Web Signature | Luís Cobucci
league/event | 2.2.0 | MIT | Event package | Frank de Jonge
league/oauth2-server | dev-v9.0.0-alpha | MIT | A lightweight and powerful OAuth 2.0 authorization and resource server library with support for all the core specification grants. This library will allow you to secure your API with OAuth and allow your applications users to approve apps that want to access their data from your API. | Alex Bilbie and Andy Millington
league/uri | 6.7.2 | MIT | URI manipulation library | Ignace Nyamagana Butera
league/uri-components | 2.4.2 | MIT | URI components manipulation library | Ignace Nyamagana Butera
league/uri-interfaces | 2.3.0 | MIT | Common interface for URI representation | Ignace Nyamagana Butera
liuggio/statsd-php-client | 1.0.18 | MIT | Statsd (Object Oriented) client library for PHP | Giulio De Donato
maxmind-db/reader | 1.11.1 | Apache-2.0 | MaxMind DB Reader API | Gregory J. Oschwald
maxmind/web-service-common | 0.9.0 | Apache-2.0 | Internal MaxMind Web Service API | Gregory Oschwald
mck89/peast | 1.16.2 | BSD-3-Clause | Peast is PHP library that generates AST for JavaScript code | Marco Marchiò
monolog/monolog | 2.9.3 | MIT | Sends your logs to files, sockets, inboxes, databases and various web services | Jordi Boggiano
mustangostang/spyc | 0.6.3 | MIT | A simple YAML loader/dumper class for PHP | mustangostang
nikic/php-parser | 4.19.1 | BSD-3-Clause | A PHP parser written in PHP | Nikita Popov
nyholm/dsn | 2.0.1 | MIT | Parse your DSN strings in a powerful and flexible way | Tobias Nyholm
onoi/message-reporter | 1.4.2 | GPL-2.0-or-later | An interface to report and relay arbitrary messages to registered handlers | Jeroen De Dauw and James Hong Kong
oojs/oojs-ui | 0.50.3 | MIT | Provides library of common widgets, layouts, and windows. | Bartosz Dziewoński, Ed Sanders, James D. Forrester, Kirsten Menger-Anderson, Kunal Mehta, Moriel Schottlender, Prateek Saxena, Roan Kattouw, Thiemo Kreuz, Timo Tijhof, Trevor Parscal and Volker E.
opis/json-schema | 1.1.0 | Apache-2.0 | Json Schema Validator | Sorin Sarca and Marius Sarca
pear/console_getopt | 1.4.3 | BSD-2-Clause | More info available on: http://pear.php.net/package/Console_Getopt | Andrei Zmievski, Stig Bakken and Greg Beaver
pear/mail | 1.6.0 | BSD-3-Clause | Class that provides multiple interfaces for sending emails. | Chuck Hagenbuch, Armin Graefe, Richard Heyes and Aleksander Machniak
pear/mail_mime | 1.10.12 | BSD-3-Clause | Mail_Mime provides classes to create MIME messages | Cipriano Groenendal and Aleksander Machniak
pear/net_smtp | 1.12.1 | BSD-2-Clause | An implementation of the SMTP protocol | Jon Parise, Chuck Hagenbuch and Armin Graefe
pear/net_socket | 1.2.2 | PHP License | More info available on: http://pear.php.net/package/Net_Socket | Chuck Hagenbuch, Aleksander Machniak and Stig Bakken
pear/net_url2 | 2.2.2 | BSD-3-Clause | Class for parsing and handling URL. Provides parsing of URLs into their constituent parts (scheme, host, path etc.), URL generation, and resolving of relative URLs. | David Coallier, Tom Klingenberg and Christian Schmidt
pear/pear-core-minimal | 1.10.15 | BSD-3-Clause | Minimal set of PEAR core files to be used as composer dependency | Christian Weiske
pear/pear_exception | 1.0.2 | BSD-2-Clause | The PEAR Exception base class. | Helgi Thormar and Greg Beaver
pimple/pimple | 3.5.0 | MIT | Pimple, a simple Dependency Injection Container | Fabien Potencier
psr/container | 1.1.2 | MIT | Common Container Interface (PHP FIG PSR-11) | PHP-FIG
psr/http-client | 1.0.3 | MIT | Common interface for HTTP clients | PHP-FIG
psr/http-factory | 1.0.2 | MIT | Common interfaces for PSR-7 HTTP message factories | PHP-FIG
psr/http-message | 1.1 | MIT | Common interface for HTTP messages | PHP-FIG
psr/log | 1.1.4 | MIT | Common interface for logging libraries | PHP-FIG
psr/simple-cache | 1.0.1 | MIT | Common interfaces for simple caching | PHP-FIG
psy/psysh | 0.12.3 | MIT | An interactive shell for modern PHP. | Justin Hileman
ralouphie/getallheaders | 3.0.3 | MIT | A polyfill for getallheaders. | Ralph Khattar
ramsey/collection | 1.3.0 | MIT | A PHP library for representing and manipulating collections. | Ben Ramsey
ramsey/uuid | 4.2.3 | MIT | A PHP library for generating and working with universally unique identifiers (UUIDs). |
react/promise | 2.11.0 | MIT | A lightweight implementation of CommonJS Promises/A for PHP | Jan Sorgalla, Christian Lück, Cees-Jan Kiewiet and Chris Boden
ruflin/elastica | 7.3.1 | MIT | Elasticsearch Client | Nicolas Ruflin
serialization/serialization | 4.0.0 | GPL-2.0+ | Library defining a Serializer and a Deserializer interface and basic utilities | Jeroen De Dauw
spomky-labs/base64url | 2.0.4 | MIT | Base 64 URL Safe Encoding/Decoding PHP Library | Florent Morselli
spomky-labs/cbor-php | 2.1.0 | MIT | CBOR Encoder/Decoder for PHP | Florent Morselli and All contributors
swaggest/json-diff | 3.11.0 | MIT | JSON diff/rearrange/patch/pointer library for PHP | Viacheslav Poturaev
symfony/console | 5.4.36 | MIT | Eases the creation of beautiful and testable command line interfaces | Fabien Potencier and Symfony Community
symfony/deprecation-contracts | 2.5.3 | MIT | A generic function and convention to trigger deprecation notices | Nicolas Grekas and Symfony Community
symfony/polyfill-php73 | 1.30.0 | MIT | Symfony polyfill backporting some PHP 7.3+ features to lower PHP versions | Nicolas Grekas and Symfony Community
symfony/polyfill-php80 | 1.29.0 | MIT | Symfony polyfill backporting some PHP 8.0+ features to lower PHP versions | Ion Bazan, Nicolas Grekas and Symfony Community
symfony/polyfill-php81 | 1.29.0 | MIT | Symfony polyfill backporting some PHP 8.1+ features to lower PHP versions | Nicolas Grekas and Symfony Community
symfony/polyfill-php82 | 1.29.0 | MIT | Symfony polyfill backporting some PHP 8.2+ features to lower PHP versions | Nicolas Grekas and Symfony Community
symfony/polyfill-php83 | 1.29.0 | MIT | Symfony polyfill backporting some PHP 8.3+ features to lower PHP versions | Nicolas Grekas and Symfony Community
symfony/process | 5.4.36 | MIT | Executes commands in sub-processes | Fabien Potencier and Symfony Community
symfony/service-contracts | 2.4.1 | MIT | Generic abstractions related to writing services | Nicolas Grekas and Symfony Community
symfony/string | 5.4.36 | MIT | Provides an object-oriented API to strings and deals with bytes, UTF-8 code points and grapheme clusters in a unified way | Nicolas Grekas and Symfony Community
symfony/translation | 5.4.35 | MIT | Provides tools to internationalize your application | Fabien Potencier and Symfony Community
symfony/translation-contracts | 2.5.3 | MIT | Generic abstractions related to translation | Nicolas Grekas and Symfony Community
symfony/validator | 5.4.38 | MIT | Provides tools to validate values | Fabien Potencier and Symfony Community
symfony/var-dumper | 5.4.38 | MIT | Provides mechanisms for walking through any arbitrary PHP variable | Nicolas Grekas and Symfony Community
symfony/yaml | 5.4.39 | MIT | Loads and dumps YAML files | Fabien Potencier and Symfony Community
thecodingmachine/safe | 1.3.3 | MIT | PHP core functions that throw exceptions instead of returning FALSE on error |
web-auth/cose-lib | 3.3.12 | MIT | CBOR Object Signing and Encryption (COSE) For PHP | Florent Morselli and All contributors
web-auth/metadata-service | 3.3.12 | MIT | Metadata Service for FIDO2/Webauthn | Florent Morselli and All contributors
web-auth/webauthn-lib | 3.3.12 | MIT | FIDO2/Webauthn Support For PHP | Florent Morselli and All contributors
wikimedia/assert | 0.5.1 | MIT | Provides runtime assertions | Daniel Kinzler and Thiemo Kreuz
wikimedia/at-ease | 2.1.0 | GPL-2.0-or-later | Safe replacement to @ for suppressing warnings. | Tim Starling and MediaWiki developers
wikimedia/base-convert | 2.0.2 | GPL-2.0-or-later | Convert an arbitrarily-long string from one numeric base to another, optionally zero-padding to a minimum column width. | Brion Vibber and Tyler Romeo
wikimedia/bcp-47-code | 2.0.0 | GPL-2.0-or-later | Simple interface representing languages which have a BCP 47 code | C. Scott Ananian
wikimedia/cdb | 3.0.0 | GPL-2.0-or-later | Constant Database (CDB) wrapper library for PHP. Provides pure-PHP fallback when dba_* functions are absent. | Tim Starling, Chad Horohoe, Ori Livneh and Daniel Kinzler
wikimedia/cldr-plural-rule-parser | 2.0.0 | GPL-2.0-or-later | Evaluates plural rules specified in the CLDR project notation. | Tim Starling and Niklas Laxström
wikimedia/common-passwords | 0.5.0 | MIT | List of the 100,000 most commonly used passwords | Sam Reed
wikimedia/composer-merge-plugin | 2.1.0 | MIT | Composer plugin to merge multiple composer.json files | Bryan Davis
wikimedia/css-sanitizer | 5.3.0 | Apache-2.0 | Classes to parse and sanitize CSS | Brad Jorsch
wikimedia/equivset | 1.6.1 | GPL-2.0-or-later | Visually Equivalent Set of UTF-8 Characters | Brion Vibber and David Barratt
wikimedia/html-formatter | 4.1.0 | GPL-2.0-or-later | Performs transformations of HTML by wrapping around libxml2 and working around its countless bugs. | MediaWiki contributors
wikimedia/idle-dom | 1.0.0 | MIT | DOM interfaces automatically generated from WebIDL | C. Scott Ananian
wikimedia/ip-utils | 5.0.0 | GPL-2.0-or-later | Parse, match, and analyze IP addresses and CIDR ranges | MediaWiki developers
wikimedia/json-codec | 3.0.1 | GPL-2.0-or-later | Interfaces to serialize and deserialize PHP objects to/from JSON | Petr Pchelko, Daniel Kinzler and C. Scott Ananian
wikimedia/langconv | 0.4.2 | GPL-2.0-or-later | Finite-State Transducer implementation of MediaWiki LanguageConverter | Wikimedia Parsing Team and the broader MediaWiki community
wikimedia/less.php | 4.4.1 | Apache-2.0 | PHP port of the LESS processor | Timo Tijhof, Josh Schmidt, Matt Agar and Martin Jantošovič
wikimedia/lucene-explain-parser | 2.0.0 | Apache-2.0 | Parsing and pretty-printing Lucene explain data | Erik Bernhardson and Stanislav Malyshev
wikimedia/metrics-platform | 4.2.1 | GPL-2.0-or-later | The PHP Metrics Platform Client. | Michael Holloway, Jason Linehan and Sam Smith
wikimedia/minify | 2.7.0 | Apache-2.0 | Minification of JavaScript code and CSS stylesheets. | Paul Copperman, Trevor Parscal, Timo Tijhof and Roan Kattouw
wikimedia/normalized-exception | 1.0.1 | MIT | A helper for making exceptions play nice with PSR-3 logging | Gergő Tisza
wikimedia/object-factory | 5.0.1 | GPL-2.0-or-later | Construct objects from configuration instructions | Bryan Davis
wikimedia/parsoid | 0.20.0-a12 | GPL-2.0-or-later | Parsoid, a bidirectional parser between wikitext and HTML5 | Wikimedia Content Transform Team and the broader MediaWiki community
wikimedia/php-session-serializer | 2.0.1 | GPL-2.0-or-later | Provides methods like PHP's session_encode and session_decode that don't mess with $_SESSION | Brad Jorsch
wikimedia/purtle | 1.0.8 | GPL-2.0-or-later | Fast streaming RDF serializer | Daniel Kinzler, Stanislav Malyshev, Thiemo Kreuz and C. Scott Ananian
wikimedia/relpath | 4.0.0 | MIT | Work with file paths to join or find the relative path | Ori Livneh
wikimedia/remex-html | 4.1.0 | MIT | Fast HTML 5 parser | Tim Starling
wikimedia/request-timeout | 1.2.0 | MIT | Request timeout library for Excimer with plain PHP fallback | Tim Starling
wikimedia/running-stat | 2.1.0 | GPL-2.0-or-later | PHP implementations of online statistical algorithms | Ori Livneh
wikimedia/scoped-callback | 4.0.0 | GPL-2.0-or-later | Make a callback run when a dummy object leaves the scope. | Aaron Schulz
wikimedia/services | 3.0.0 | GPL-2.0-or-later | Generic service to manage named services using lazy instantiation based on instantiator callback functions | Daniel Kinzler
wikimedia/shellbox | 4.0.2 | MIT | Library and server for containerized shell execution | Tim Starling, Kunal Mehta and Max Semenik
wikimedia/testing-access-wrapper | 3.0.0 | GPL-2.0-or-later | A simple helper class to access non-public elements of a class when testing. | Adam Roses Wight, Brad Jorsch and Gergő Tisza
wikimedia/textcat | 2.0.0 | LGPL-2.1-only | PHP port of the TextCat language guesser utility, see http://odur.let.rug.nl/~vannoord/TextCat/. | Trey Jones and Stanislav Malyshev
wikimedia/timestamp | 4.1.1 | GPL-2.0-or-later | Creation, parsing, and conversion of timestamps | Tyler Romeo
wikimedia/utfnormal | 4.0.0 | GPL-2.0-or-later | Contains Unicode normalization routines, including both pure PHP implementations and automatic use of the 'intl' PHP extension when present | Brion Vibber
wikimedia/wait-condition-loop | 2.0.2 | GPL-2.0-or-later | Wait loop that reaches a condition or times out | Aaron Schulz
wikimedia/wikipeg | 4.0.0 | MIT | Parser generator for JavaScript and PHP |
wikimedia/wrappedstring | 4.0.1 | MIT | Automatically compact sequentially-outputted strings that share a common prefix / suffix pair. | Timo Tijhof
wikimedia/xmp-reader | 0.9.1 | GPL-2.0-or-later | Reader for XMP data containing properties relevant to images | Brian Wolff
wikimedia/zest-css | 3.0.1 | MIT | Fast, lightweight, extensible CSS selector engine for PHP | Christopher Jeffrey and C. Scott Ananian
wmde/php-vuejs-templating | 2.0.0 | LGPL-2.1-only | PHP implementation of Vue.js templating engine | Aleksey Bekh-Ivanov
zordius/lightncandy | 1.2.6 | MIT | An extremely fast PHP implementation of handlebars ( http://handlebarsjs.com/ ) and mustache ( http://mustache.github.io/ ). | Zordius Chen

### Installed client-side libraries

Library | Version | License | Authors | Source
--- | --- | --- | --- | ---
CLDRPluralRuleParser | 1.3.1-0dda851 | MIT | Santhosh Thottingal | MediaWiki
Color Picker | 1.3.5 | MIT | Taufik Nurrohman and other contributors | VisualEditor
DOMPurify | 2.4.4 | MPL-2.0 OR Apache-2.0 | Mario Heiderich and other contributors | VisualEditor
Diff Match and Patch | — | Apache-2.0 | Google, Inc. | VisualEditor
PapaParse | 5.3.2 | MIT | Matthew Holt and other contributors | VisualEditor
RangeFix | 0.2.10 | MIT | Ed Sanders and other contributors | VisualEditor
Tree Differ | 1.0.2 | MIT | Thalia Chan | VisualEditor
Universal Language Selector data | — | MIT OR GPL-2.0+ | Wikimedia Language Engineering Team and other contributors | VisualEditor
VisualEditor | Development branch | MIT | VisualEditor Team and other contributors | VisualEditor
ace | 1.32.7 | BSD-3-Clause | Ace authors – https://ace.c9.io/ | CodeEditor
codemirror | 5.65.15 | MIT | CodeMirror authors | CodeMirror
codex-design-tokens | 1.8.0 | GPL-2.0+ | Design System team, Wikimedia Foundation | MediaWiki
codex-icons | 1.8.0 | MIT | Design System team, Wikimedia Foundation | MediaWiki
codex | 1.8.0 | GPL-2.0+ | Design System team, Wikimedia Foundation | MediaWiki
fetch-polyfill | 3.6.2 | MIT | GitHub, Inc. | MediaWiki
intersection-observer | 0.12.0 | Apache-2.0 | Philip Walton | MediaWiki
jquery.chosen | 1.8.2 | MIT | Patrick Filler for Harvest, Matthew Lettini, Patrick Filler, Ken Earley, Christophe Coevoet, Koen Punt, and T.J. Schuck. | MediaWiki
jquery.client | 3.0.0 | MIT | Trevor Parscal, Timo Tijhof, and Roan Kattouw | MediaWiki
jquery.i18n | 1.0.10 | MIT OR GPL-2.0-or-later | Language Engineering team, Wikimedia Foundation | MediaWiki
jquery.ui | 1.9.2 | MIT | OpenJS Foundation and other contributors | MediaWiki
jquery | 3.7.1 | MIT | OpenJS Foundation and other contributors | MediaWiki
jsdifflib | 1 | BSD-3-Clause | Snowtide Informatics Systems, Inc. | VisualEditor
mathjax | 3.2.2 | Apache-2.0 | MathJax Consortium | Math
metrics-platform | 84ed8dcbe7c9 | GPL-2.0+ | — | EventLogging
moment-timezone | 0.5.27 | MIT | — | DiscussionTools
moment | 2.25.2 | MIT | JS Foundation and other contributors | MediaWiki
mustache | 4.2.0 | MIT | Michael Jackson, Jan Lehnardt, Phillip Johnsen, and other contributors | MediaWiki
ogv.js | 1.9.0 | MIT | Brooke Vibber <bvibber@pobox.com> | TimedMediaHandler
oojs | 7.0.1 | MIT | OOjs Team and other contributors | MediaWiki
ooui | 0.50.3 | MIT | OOUI Team and other contributors | MediaWiki
pako | 2.1.0 | MIT AND Zlib | Andrei Tuputcyn, Vitaly Puzrin, Friedel Ziegelmayer, Kirill Efimov, Jean-loup Gailly, and Mark Adler | MediaWiki
pinia | 2.0.16 | MIT | Eduardo San Martin Morote | MediaWiki
quagga2 | 1.8.2 | MIT | Christoph Oberhofer, Eric Blade and other contributors | Citoid
qunitjs | 2.20.0 | MIT | OpenJS Foundation and other contributors | MediaWiki
sinonjs | 1.17.7 | BSD-3-Clause | Christian Johansen and other contributors | MediaWiki
socket.io-client | 4.4.0 | MIT | Guillermo Rauch and other contributors | VisualEditor
spark-md5 | 3.0.0 | WTFPL OR MIT | André Cruz | VisualEditor
swagger-ui | 4.15.5 | Apache-2.0 | Kyle Shockey, Tony Tam, Vladimír Gorej, and others | MediaWiki
three | r88 | MIT | — | 3D
url | 3.111.0-0ece79ce32 | MIT | Financial Times | MediaWiki
video.js | 8.6.2 | Apache-2.0 | Brightcove, Inc. <https://www.brightcove.com/> | TimedMediaHandler
vue-demi | 0.14.7 | MIT | Anthony Fu | MediaWiki
vue | 3.4.27 | MIT | Yuxi (Evan) You | MediaWiki
vuex | 4.0.2 | MIT | Yuxi (Evan) You | MediaWiki

## Parser extension tags

`<categorytree>`, `<ce>`, `<charinsert>`, `<chem>`, `<dynamicpagelist>`, `<gallery>`, `<graph>`, `<hiero>`, `<imagemap>`, `<indicator>`, `<inputbox>`, `<langconvert>`, `<languages>`, `<mapframe>`, `<maplink>`, `<math>`, `<nowiki>`, `<phonos>`, `<poem>`, `<pre>`, `<ref>`, `<references>`, `<rss>`, `<score>`, `<section>`, `<source>`, `<syntaxhighlight>`, `<templatedata>`, `<templatestyles>` and `<timeline>`

## Parser function hooks

`{{anchorencode}}`, `{{#babel}}`, `{{BASEPAGENAME}}`, `{{BASEPAGENAMEE}}`, `{{bidi}}`, `{{canonicalurl}}`, `{{canonicalurle}}`, `{{CASCADINGSOURCES}}`, `{{#categorytree}}`, `{{#commaseparatedlist}}`, `{{DEFAULTSORT}}`, `{{DISPLAYTITLE}}`, `{{#expr}}`, `{{filepath}}`, `{{#FORMAL}}`, `{{#formatdate}}`, `{{formatnum}}`, `{{FULLPAGENAME}}`, `{{FULLPAGENAMEE}}`, `{{fullurl}}`, `{{fullurle}}`, `{{gender}}`, `{{grammar}}`, `{{#if}}`, `{{#ifeq}}`, `{{#iferror}}`, `{{#ifexist}}`, `{{#ifexpr}}`, `{{int}}`, `{{#invoke}}`, `{{#language}}`, `{{lc}}`, `{{lcfirst}}`, `{{localurl}}`, `{{localurle}}`, `{{#lqtpagelimit}}`, `{{#lst}}`, `{{#lsth}}`, `{{#lstx}}`, `{{NAMESPACE}}`, `{{NAMESPACEE}}`, `{{NAMESPACENUMBER}}`, `{{noexternallanglinks}}`, `{{ns}}`, `{{nse}}`, `{{NUMBERINGROUP}}`, `{{NUMBEROFACTIVEUSERS}}`, `{{NUMBEROFADMINS}}`, `{{NUMBEROFARTICLES}}`, `{{NUMBEROFEDITS}}`, `{{NUMBEROFFILES}}`, `{{NUMBEROFPAGES}}`, `{{NUMBEROFUSERS}}`, `{{padleft}}`, `{{padright}}`, `{{pageid}}`, `{{PAGENAME}}`, `{{PAGENAMEE}}`, `{{PAGESINCATEGORY}}`, `{{PAGESIZE}}`, `{{plural}}`, `{{#property}}`, `{{PROTECTIONEXPIRY}}`, `{{PROTECTIONLEVEL}}`, `{{#rel2abs}}`, `{{REVISIONDAY}}`, `{{REVISIONDAY2}}`, `{{REVISIONID}}`, `{{REVISIONMONTH}}`, `{{REVISIONMONTH1}}`, `{{REVISIONTIMESTAMP}}`, `{{REVISIONUSER}}`, `{{REVISIONYEAR}}`, `{{ROOTPAGENAME}}`, `{{ROOTPAGENAMEE}}`, `{{#special}}`, `{{#speciale}}`, `{{#statements}}`, `{{SUBJECTPAGENAME}}`, `{{SUBJECTPAGENAMEE}}`, `{{SUBJECTSPACE}}`, `{{SUBJECTSPACEE}}`, `{{SUBPAGENAME}}`, `{{SUBPAGENAMEE}}`, `{{#switch}}`, `{{#tag}}`, `{{TALKPAGENAME}}`, `{{TALKPAGENAMEE}}`, `{{TALKSPACE}}`, `{{TALKSPACEE}}`, `{{#target}}`, `{{#time}}`, `{{#timel}}`, `{{#titleparts}}`, `{{#translation}}`, `{{uc}}`, `{{ucfirst}}`, `{{urlencode}}` and `{{#useliquidthreads}}` visited from 0.0.0.0
Retrieved from "https://www.mediawiki.org/wiki/Special:Version"